rayoptics.oprops package
========================

.. automodule:: rayoptics.oprops
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

rayoptics.oprops.doe module
---------------------------

.. automodule:: rayoptics.oprops.doe
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.oprops.thinlens module
--------------------------------

.. automodule:: rayoptics.oprops.thinlens
   :members:
   :undoc-members:
   :show-inheritance:

